@@ -571,6 +571,8 @@ void BattleRoomTab::UpdateUser(User& user, bool userJustAdded)
 	m_ready_chk->SetValue(bs.ready);
 	// Enable or disable widgets' sensitivity as appropriate.
 	if (bs.spectator) {
+		m_start_btn->SetLabel(_("Spectate"));
+		m_start_btn->SetToolTip(_("Watch a running match (you are a spectator)"));
 		m_side_sel->Disable();
 		m_ally_sel->Disable();
 		m_team_sel->Disable();
@@ -586,6 +588,8 @@ void BattleRoomTab::UpdateUser(User& user, bool userJustAdded)
 			OnAutolaunch();
 		}
 	} else { // we are player
+		m_start_btn->SetLabel(_("Start"));
+		m_start_btn->SetToolTip(_("Start the battle"));
 		m_side_sel->Enable();
 		m_ally_sel->Enable();
 		m_team_sel->Enable();
@@ -625,42 +629,70 @@ void BattleRoomTab::OnPromote(wxCommandEvent& /*unused*/)
 	}
 }
 
+/*
+ * Running? Spec? Founder? Action
+ *    0       0      0     DL -> ready -> Ring -> OpponentCheck -> !start
+ *    0       0      1     DL -> ready -> Ring -> OpponentCheck -> StartHB
+ *    0       1      0     DL -> ready -> "Unspec to play"
+ *    0       1      1     DL -> ready -> "Unspec to play"
+ *    1       0      0     DL -> ready -> start
+ *    1       0      1     DL -> ready -> start
+ *    1       1      0     DL -> ready -> start
+ *    1       1      1     DL -> ready -> start
+ */
 void BattleRoomTab::OnStart(wxCommandEvent& /*unused*/)
 {
 	slLogDebugFunc("");
 	if (m_battle == nullptr)
 		return;
 
+	if (ui().IsSpringRunning()) {
+		customMessageBoxModal(SL_MAIN_ICON, _("You are already playing/spectating."), _("Error"));
+		return;
+	}
+
+	if (ui().NeedsDownload(m_battle)) {
+		customMessageBoxModal(SL_MAIN_ICON, _("You must download missing content before you"
+		  " can start or wait for the downloads to finish if they had been started already."),
+		  _("Error"));
+		return;
+	}
+
 	//start manually clicked, force start
 	m_battle->SetAutolaunchGame(true);
+	m_ready_chk->SetValue(true); OnImReady();
 
-	if (m_battle->IsFounderMe()) {
-		m_battle->GetMe().BattleStatus().ready = true;
-		if (!m_battle->IsEveryoneReady()) {
-			int answer = customMessageBox(SL_MAIN_ICON, _("Some Players are not ready yet\nDo you want to force start?"), _("Not ready"), wxYES_NO | wxCANCEL);
-			if (answer == wxNO)
-				return;
-		}
-
-		m_battle->SaveMapDefaults(); // save map presets
-
-		m_battle->StartHostedBattle();
-	} else {
-		if (ui().NeedsDownload(m_battle)) {
-			wxLogWarning("Cannot start, need to download first!");
-			return;
-		}
-
-		if (m_battle->GetFounder().Status().in_game) {
-			if (!ui().IsSpringRunning())
-				m_battle->StartSpring();
-			else
-				customMessageBoxModal(SL_MAIN_ICON, _("Spring is already running."), _("Error"));
-		} else {
-			m_battle->m_autohost_manager->GetAutohostHandler().Start();
-			//customMessageBoxNoModal( SL_MAIN_ICON, _("Host is not ingame."), _("Error") );
+	// Is remote battle running?
+	if (m_battle->GetFounder().Status().in_game) {
+		m_battle->StartSpring();
+	} else { // No, it is not running.
+		if (m_battle->GetMe().BattleStatus().spectator) {
+			customMessageBoxModal(SL_MAIN_ICON,
+			  _("No battle is running. You must be a player to start"), _("Error"));
+		} else { // I am a player
+			if (m_battle->IsEveryoneReady()) {
+				if (m_battle->DoesOpponentExist()) {
+					if (m_battle->IsFounderMe()) {
+						m_battle->SaveMapDefaults(); // save map presets
+						m_battle->StartHostedBattle();
+					} else {
+						m_battle->m_autohost_manager->GetAutohostHandler().Start();
+					}
+				} else {
+					customMessageBoxModal(SL_MAIN_ICON,
+					  _("A battle with no opponents is no battle at all" // ...
+					    " (Hint: add a bot and try again)."), _("Error"));
+				}
+			} else {
+				int answer = customMessageBox(SL_MAIN_ICON,
+				  _("Some players are not ready, ring them?"),
+				  _("Not ready"), wxYES | wxCANCEL);
+				if (answer == wxYES)
+					m_battle->RingNotSyncedAndNotReadyPlayers();
+			}
 		}
 	}
+
 	//reset to value from gui
 	m_battle->SetAutolaunchGame(m_autolaunch_chk->GetValue());
 }
@@ -763,13 +795,18 @@ void BattleRoomTab::OnAutolaunch()
 }
 
 
-void BattleRoomTab::OnImReady(wxCommandEvent& /*unused*/)
+void BattleRoomTab::OnImReady()
 {
 	if (!m_battle)
 		return;
 	m_battle->SetImReady(m_ready_chk->GetValue());
 }
 
+void BattleRoomTab::OnImReady(wxCommandEvent& /*unused*/)
+{
+	OnImReady();
+}
+
 
 void BattleRoomTab::OnLock(wxCommandEvent& /*unused*/)
 {
@@ -839,9 +876,21 @@ void BattleRoomTab::OnImSpec(wxCommandEvent& /*unused*/)
 {
 	if (!m_battle)
 		return;
-	m_battle->ForceSpectator(m_battle->GetMe(), m_spec_chk->GetValue());
-}
 
+	// Prevent taking same team ID as someone else when un-speccing.
+	if (m_spec_chk->IsChecked()) {
+		m_battle->ForceSpectator(m_battle->GetMe(), true);
+	} else {
+		int team = m_battle->GetFreeTeam(/*excludeme=*/false);
+		m_team_sel->SetSelection(team);
+		UserBattleStatus& myStatus = m_battle->GetMe().BattleStatus();
+		// Due to ForceSpectator working on a local copy, one way to implement this is by:
+		int oldteam = myStatus.team;
+		myStatus.team = team;
+		m_battle->ForceSpectator(m_battle->GetMe(), false);
+		myStatus.team = oldteam;
+	}
+}
 
 void BattleRoomTab::OnTeamSel(wxCommandEvent& /*unused*/)
 {
