@@ -26,9 +26,9 @@ void LibnotifyNotification::Show(const wxBitmap& icon, const size_t /*pos*/, con
 	NotifyNotification* n;
 	notify_init("Test");
 #if !defined(NOTIFY_VERSION_MINOR) || (NOTIFY_VERSION_MAJOR == 0 && NOTIFY_VERSION_MINOR < 7)
-	n = notify_notification_new(getSpringlobbyName().c_str(), data.second.mb_str(), NULL, NULL);
+	n = notify_notification_new(GetSpringlobbyName().c_str(), data.second.mb_str(), NULL, NULL);
 #else
-	n = notify_notification_new(getSpringlobbyName().c_str(), data.second.mb_str(), NULL);
+	n = notify_notification_new(GetSpringlobbyName().c_str(), data.second.mb_str(), NULL);
 #endif
 	notify_notification_set_timeout(n, sett().GetNotificationPopupDisplayTime() * 1000);
 
