@@ -48,7 +48,6 @@
 #include "gui/agreementdialog.h"
 #include "updatehelper.h"
 #include "gui/customdialogs.h"
-#include "httpfile.h"
 #include "gui/textentrydialog.h"
 #include "log.h"
 #include "settings.h"
@@ -62,7 +61,6 @@
 
 
 SLCONFIG("/General/AutoUpdate", true, "Determines if springlobby should check for updates on startup");
-SLCONFIG("/General/LastUpdateCheck", 0L, "Last time springlobby checked for an update");
 SLCONFIG("/GUI/StartTab", (long)MainWindow::PAGE_BATTLELIST, "which tab to show on startup");
 SLCONFIG("/Chat/BroadcastEverywhere", true, "setting to spam the server messages in all channels");
 SLCONFIG("/Server/Autoconnect", false, "Connect to server on startup");
@@ -238,7 +236,7 @@ void Ui::ConsoleHelp()
 		wxLogError(_T("GetActiveChatPanel() failed: couldn't find current active panel."));
 		return;
 	}
-	panel->ClientMessage(_("SpringLobby commands help."));
+	panel->ClientMessage(wxString::Format(_("%s commands help:"), GetSpringlobbyName()));
 	panel->ClientMessage(wxEmptyString);
 	panel->ClientMessage(_("Global commands:"));
 	panel->ClientMessage(_("  \"/away\" - Sets your status to away."));
@@ -254,9 +252,11 @@ void Ui::ConsoleHelp()
 	panel->ClientMessage(_("  \"/part\" - Leaves current channel."));
 	panel->ClientMessage(_("  \"/p\" - Alias to /part."));
 	panel->ClientMessage(_("  \"/rename newalias\" - Changes your nickname to newalias."));
-	panel->ClientMessage(_("  \"/sayver\" - Says what version of SpringLobby you have in chat."));
+	panel->ClientMessage(wxString::Format(
+	  _("  \"/sayver\" - Says what version of %s you have in chat."), GetSpringlobbyName()));
 	panel->ClientMessage(_("  \"/testmd5 text\" - Returns md5-b64 hash of given text."));
-	panel->ClientMessage(_("  \"/ver\" - Displays what version of SpringLobby you have."));
+	panel->ClientMessage(wxString::Format(
+	  _("  \"/ver\" - Displays what version of %s you have."), GetSpringlobbyName()));
 	panel->ClientMessage(_("  \"/clear\" - Clears all text from current chat panel"));
 	panel->ClientMessage(wxEmptyString);
 	panel->ClientMessage(_("Chat commands:"));
@@ -274,11 +274,10 @@ ChatPanel* Ui::GetChannelChatPanel(const wxString& channel)
 ////////////////////////////////////////////////////////////////////////////////////////////
 // EVENTS
 ////////////////////////////////////////////////////////////////////////////////////////////
-
 //! @brief Called when connected to a server
 //!
 //! @todo Display in servertab
-void Ui::OnConnected(IServer& server, const wxString& server_name, const wxString& version, bool /*supported*/)
+void Ui::OnConnected(IServer& server, const wxString& server_name, const wxString& /*version*/, bool /*supported*/)
 {
 	slLogDebugFunc("");
 
@@ -291,14 +290,6 @@ void Ui::OnConnected(IServer& server, const wxString& server_name, const wxStrin
 	mw().GetBattleListTab().OnConnected();
 
 	ReopenServerTab();
-
-	if (version.empty()) {
-		wxLogWarning("default version supplied from server is empty!");
-		return;
-	}
-	std::map<std::string, LSL::SpringBundle> enginebundles = SlPaths::GetSpringVersionList();
-	if (!SlPaths::GetCompatibleVersion(STD_STRING(version)).empty())
-		return;
 }
 
 void Ui::OnLoggedIn()
@@ -747,12 +738,7 @@ void Ui::OnInit()
 		mw().ShowTab(cfg().ReadLong(_T( "/GUI/StartTab" )));
 		//don't ask for updates on first run, that's a bit much for a newbie
 		if (cfg().ReadBool(_T("/General/AutoUpdate"))) {
-			const time_t now = time(0);
-			const size_t lastcheck = cfg().ReadLong(_T("/General/LastUpdateCheck"));
-			if (now - lastcheck > 3600) {
-				CheckForUpdates(false);
-				cfg().Write(_T("/General/LastUpdateCheck"), (long)now);
-			}
+			CheckForUpdates(false);
 		}
 	}
 }
@@ -794,32 +780,37 @@ void Ui::OnLobbyDownloaded(wxCommandEvent& data)
 	mw().Close();
 }
 
-void Ui::CheckForUpdates(bool show)
+void Ui::CheckForUpdates(bool is_interactive)
 {
-	std::string latestversion = GetHttpFile(GetLatestVersionUrl());
-	latestversion = STD_STRING(TowxString(latestversion).Trim().Trim(false));
+	std::string latestversion = GetLatestVersion(is_interactive);
 
 	if (latestversion.empty()) {
-		if (show) {
-			customMessageBoxModal(SL_MAIN_ICON, _("There was an error checking for the latest version.\nPlease try again later.\nIf the problem persists, please use Help->Report Bug to report this bug."), _("Error"));
+		if (is_interactive) {
+			customMessageBoxModal(SL_MAIN_ICON, _(
+			  "There was an error checking for the latest version.\n"
+			  "Please try again later.\n"
+			  "If the problem persists, please use Help->Report Bug to report this bug."),
+			  _("Error"));
 		}
 		return;
 	}
 	//get current rev w/o AUX_VERSION added
-	const std::string myVersion = getSpringlobbyVersion();
+	const std::string myVersion = GetSpringlobbyVersion();
 
 	const wxString msg = _("Your Version: ") + myVersion + _T("\n") + _("Latest Version: ") + latestversion;
 	if (latestversion == myVersion) {
-		if (show) {
-			customMessageBoxModal(SL_MAIN_ICON, _("Your SpringLobby version is up to date.\n\n") + msg, _("Up to Date"));
+		if (is_interactive) {
+			customMessageBoxModal(SL_MAIN_ICON, wxString::Format(
+			  _("Your %s version is up to date."), GetSpringlobbyName())
+			  + _T("\n\n") + msg, _("Up to Date"));
 		}
 		return;
 	}
 #ifdef __WXMSW__
 	const wxString message = wxString::Format(_("Your %s version is not up to date.") + _T("\n\n%s\n\n") + _("Would you like to update to the new version?"),
-						  TowxString(getSpringlobbyName()).c_str(),
+						  TowxString(GetSpringlobbyName()).c_str(),
 						  msg.c_str());
-	const wxString heading = _("Update Springlobby?");
+	const wxString heading = wxString::Format(_("Update %s?"), GetSpringlobbyName());
 	if (!Ask(heading, message))
 		return;
 	try {
@@ -839,7 +830,9 @@ void Ui::CheckForUpdates(bool show)
 #else
 	const wxString motivation = _("Please update to the latest version before reporting bugs.");
 	const wxString doublenl = _T("\n\n");
-	customMessageBoxModal(SL_MAIN_ICON, _("Your SpringLobby version is not up to date.") + doublenl + msg + doublenl + motivation, _("Not up to Date"));
+	customMessageBoxModal(SL_MAIN_ICON,
+	  wxString::Format(_("Your %s version is not up to date."), GetSpringlobbyName())
+	  + doublenl + msg + doublenl + motivation, _("Not up to Date"));
 #endif
 }
 
