@@ -105,16 +105,6 @@ LSL::lslColor IBattle::GetFixColour(int i) const
 	return palette[i];
 }
 
-int IBattle::GetPlayerNum(const User& user) const
-{
-	for (user_map_t::size_type i = 0; i < GetNumUsers(); i++) {
-		if (&GetUser(i) == &user)
-			return i;
-	}
-	ASSERT_EXCEPTION(false, _T("The player is not in this game."));
-	return -1;
-}
-
 class DismissColor
 {
 private:
@@ -306,16 +296,16 @@ void IBattle::OnUserBattleStatusUpdated(User& user, UserBattleStatus status)
 		UserBattleStatus& loopstatus = loopuser.BattleStatus();
 		if (loopstatus.spectator)
 			m_opts.spectators++;
-		if (!loopstatus.IsBot()) {
-			if (!loopstatus.spectator) {
+		else  {
+			PlayerJoinedTeam(loopstatus.team);
+			PlayerJoinedAlly(loopstatus.ally);
+			if (!loopstatus.IsBot()) {
 				if (loopstatus.ready && loopstatus.spectator)
 					m_players_ready++;
 				if (loopstatus.sync)
 					m_players_sync++;
 				if (loopstatus.ready && loopstatus.sync)
 					m_players_ok++;
-				PlayerJoinedTeam(loopstatus.team);
-				PlayerJoinedAlly(loopstatus.ally);
 			}
 		}
 	}
@@ -404,6 +394,12 @@ bool IBattle::IsEveryoneReady() const
 }
 
 
+bool IBattle::DoesOpponentExist() const
+{
+	return (2 <= m_ally_sizes.size());
+}
+
+
 void IBattle::AddStartRect(unsigned int allyno, unsigned int left, unsigned int top, unsigned int right, unsigned int bottom)
 {
 	assert(allyno < MAX_TEAMS);
@@ -704,18 +700,22 @@ UserPosition IBattle::GetFreePosition()
 void IBattle::SetHostMap(const std::string& mapname, const std::string& hash)
 {
 	assert(hash.empty() || LSL::Util::MakeHashUnsigned(hash) == hash);
-	ASSERT_LOGIC(!mapname.empty(), "Battle with empty map name!");
-	if (mapname != m_host_map.name || hash != m_host_map.hash) {
-		m_map_loaded = false;
-		m_host_map.name = mapname;
-		m_host_map.hash = hash;
+	if (mapname == m_host_map.name || hash == m_host_map.hash) {
+		return;
 	}
+	m_map_loaded = mapname.empty();
+	m_host_map.name = mapname;
+	m_host_map.hash = hash;
 }
 
 
 void IBattle::SetLocalMap(const std::string& mapname)
 {
-	ASSERT_LOGIC(!mapname.empty(), "Battle with empty map name!");
+	if (mapname.empty()) {
+		wxLogWarning("Battle with empty map name!");
+		return;
+	}
+
 	LSL::UnitsyncMap map = LSL::usync().GetMap(mapname);
 	if (map.name != m_local_map.name || map.hash != m_local_map.hash) {
 		m_local_map = map;
@@ -729,19 +729,16 @@ void IBattle::SetLocalMap(const std::string& mapname)
 
 const LSL::UnitsyncMap& IBattle::LoadMap()
 {
-	if ((!m_map_loaded) && (!m_host_map.name.empty())) {
-		if (MapExists(true)) { //Check if selected map available for engine?
-			try {
-				m_local_map = LSL::usync().GetMap(m_host_map.name);
-				assert(LSL::Util::MakeHashUnsigned(m_local_map.hash) == m_local_map.hash);
-				bool options_loaded = CustomBattleOptions().loadOptions(LSL::Enum::MapOption, m_host_map.name);
-				//TODO: maybe replace this with "silent" IF operator?
-				ASSERT_EXCEPTION(options_loaded, _T("couldn't load the map options"));
-				m_map_loaded = true;
-			} catch (...) {
-			}
-		}
+	if ((m_map_loaded) || (m_host_map.name.empty()) || !MapExists(true))
+		return m_local_map;
+
+	m_local_map = LSL::usync().GetMap(m_host_map.name);
+	assert(LSL::Util::MakeHashUnsigned(m_local_map.hash) == m_local_map.hash);
+	const bool options_loaded = CustomBattleOptions().loadOptions(LSL::Enum::MapOption, m_host_map.name);
+	if (!options_loaded) {
+		wxLogWarning( _T("couldn't load the map options"));
 	}
+	m_map_loaded = true;
 	return m_local_map;
 }
 
@@ -764,7 +761,7 @@ void IBattle::SetHostGame(const std::string& gamename, const std::string& hash)
 	if ((m_host_game.name == gamename) && (m_host_game.hash == hash)) {
 		return;
 	}
-	m_game_loaded = false;
+	m_game_loaded = gamename.empty();
 	m_host_game.name = gamename;
 	m_host_game.hash = hash;
 }
@@ -787,20 +784,21 @@ void IBattle::SetLocalGame(const LSL::UnitsyncGame& mod)
 
 const LSL::UnitsyncGame& IBattle::LoadGame()
 {
-	ASSERT_LOGIC(!m_host_game.name.empty(), "m_host_game.name.empty() is FALSE");
-	if (m_game_loaded) {
+	if (m_game_loaded || m_host_game.name.empty()) {
 		return m_local_game;
 	}
 	if (!GameExists(true)) {
 		wxLogWarning("Game doesn't exist");
 		return m_local_game;
 	}
-	try {
-		SetLocalGame(LSL::usync().GetGame(m_host_game.name));
-		bool options_loaded = CustomBattleOptions().loadOptions(LSL::Enum::ModOption, m_host_game.name);
-		ASSERT_EXCEPTION(options_loaded, _T("couldn't load the game options"));
-		m_game_loaded = true;
-	} catch (...) {	}
+	SetLocalGame(LSL::usync().GetGame(m_host_game.name));
+	const bool options_loaded = CustomBattleOptions().loadOptions(LSL::Enum::ModOption, m_host_game.name);
+
+	if (!options_loaded) {
+		wxLogWarning("couldn't load the game options");
+	}
+
+	m_game_loaded = true;
 	return m_local_game;
 }
 
@@ -1061,12 +1059,6 @@ bool IBattle::IsFounder(const User& user) const
 		return false;
 }
 
-int IBattle::GetMyPlayerNum() const
-{
-	return GetPlayerNum(GetMe());
-}
-
-
 void IBattle::LoadScriptMMOpts(const std::string& sectionname, const LSL::TDF::PDataList& node)
 {
 	if (!node.ok())
