@@ -226,10 +226,6 @@ public:
 	virtual bool IsFounderMe() const;
 	virtual bool IsFounder(const User& user) const;
 
-	virtual int GetMyPlayerNum() const;
-
-	virtual int GetPlayerNum(const User& user) const;
-
 	virtual void SetHostGame(const std::string& gamename, const std::string& hash);
 	virtual void SetLocalGame(const LSL::UnitsyncGame& game);
 	virtual const LSL::UnitsyncGame& LoadGame();
@@ -245,6 +241,7 @@ public:
 	virtual void OnUserRemoved(User& user);
 
 	virtual bool IsEveryoneReady() const;
+	virtual bool DoesOpponentExist() const;
 
 	virtual void ForceSide(User& user, int side);
 	virtual void ForceAlly(User& user, int ally);
