@@ -1,38 +1,62 @@
 /* This file is part of the Springlobby (GPL v2 or later), see COPYING */
 
+#include <cstdio>
+#include <algorithm>
+#include <cstring>
+#include <mutex>
+#include <sys/time.h>
+#include <vector>
+#include <time.h>
+
 #include <wx/log.h>
-#include <boost/thread/mutex.hpp>
 
 #include "log.h"
-#include "utils/conversion.h"
 #include "gui/ui.h"
 #include "gui/mainwindow.h"
-#include "time.h"
-
-#if wxUSE_STD_IOSTREAM
-#include <iostream>
-#endif
+#include "utils/conversion.h"
+#include "downloader/lib/src/Logger.h"
 
 static bool gui = false;
 
+const char* wxLogLevelToString(wxLogLevel level)
+{
+	assert(level < 8); // just in case
+
+	static const char* levelNames[] = {
+	  "Fatal",
+	  "Error",
+	  "Warning",
+	  "Message",
+	  "Status",
+	  "Info",
+	  "Debug",
+	  "Trace"};
+
+	return levelNames[static_cast<int>(level)];
+}
+
 class myLogger : public wxLog
 {
 public:
 	~myLogger()
 	{
-		if (m_logfile != NULL) {
-			fclose(m_logfile);
-		}
+		for (FILE* lf : m_log_files)
+			fclose(lf);
 	}
 	myLogger(bool console, const wxString& logfilepath, bool /*showgui*/)
 	    : wxLog()
-	    , m_console(console)
-	    ,
 	    //		m_gui(showgui),
-	    m_logfile(NULL)
 	{
+		if (console)
+			m_log_files.push_back (stdout);
 		if (!logfilepath.empty()) {
-			m_logfile = fopen(C_STRING(logfilepath), "wb+"); // even if it returns null, wxLogStderr will switch to stderr logging, so it's fine
+			// even if it returns null, wxLogStderr will switch to stderr logging, so it's fine
+			// TODO: it will?
+			FILE* log = fopen(C_STRING(logfilepath), "wb+");
+			if (nullptr == log)
+				wxLogError ("Unable to open log file %s for writing!", logfilepath);
+			else
+				m_log_files.push_back (log);
 		}
 	}
 
@@ -57,7 +81,7 @@ public:
 	// catch and process all log messages
 	void DoLogRecord(wxLogLevel loglevel, const wxString& msg, const wxLogRecordInfo& info) override
 	{
-		boost::mutex::scoped_lock lock(m_mutex);
+		std::lock_guard<std::mutex> lock(m_mutex);
 
 		if (gui && (loglevel == wxLOG_Error || loglevel == wxLOG_FatalError)) // show user only errors
 		{
@@ -66,15 +90,37 @@ public:
 			ui().mw().GetEventHandler()->QueueEvent(event);
 		}
 
+		// only print the last src_fn_size chars of file name
+		const int src_fn_size = 20;
+		const int src_fn_offset = std::max(0, static_cast<int>(std::strlen(info.filename)) - src_fn_size);
+		const char* src_fn = info.filename + src_fn_offset;
 
-		const std::string std_msg = stdprintf("%s %s %s:%d %s\n", GetTimeString().c_str(), LogLevelToString(loglevel).c_str(), info.filename, info.line, (STD_STRING(wxString(msg))).c_str());
-		if (m_console) {
-			std::cout << std_msg;
-		}
-		if (m_logfile != NULL) {
-			fwrite(std_msg.c_str(), std_msg.length(), 1, m_logfile);
-			fflush(m_logfile);
+		const std::string log_prefix = stdprintf("%s %-7s %20.20s:%-4d",
+		  GetTimeString().c_str(), wxLogLevelToString(loglevel),
+		  src_fn, info.line);
+
+		char delim = ' '; // indicates that this is a new message, continuations use '+'
+		// sol=Start-Of-Line, eol=End-Of-Line. We have at least one execution of the below loop.
+		// eol should be one past the end character for substring length = eol - sol to work
+		for (size_t sol = 0, eol = 0; eol < msg.Len(); sol = ++eol) {
+			eol = msg.find("\n", sol);
+			if (wxString::npos == eol) {
+				eol = msg.Len();
+				if (sol >= eol) // real end condition
+					break;
+			}
+			wxString line_msg = msg.Mid(sol, eol-sol);
+
+			for (FILE* lf : m_log_files) {
+				fwrite(log_prefix.c_str(), log_prefix.length(), 1, lf);
+				fwrite(&delim, 1, 1, lf);
+				fwrite(line_msg.c_str(), line_msg.length(), 1, lf);
+				fwrite("\n", 1, 1, lf);
+			}
+			delim = '+'; // not first line any more
 		}
+
+		Flush();
 		/*
 	  if (m_gui) {
 		  ChatPanel* p = ui().mw().GetChatTab().AddChatPanel();
@@ -84,35 +130,16 @@ public:
 	  }*/
 	}
 
-	std::string LogLevelToString(wxLogLevel level)
-	{
-		assert(level < 8); // just in case
-
-		const char* levelName[] = {
-		    "Fatal",
-		    "Error",
-		    "Warning",
-		    "Message",
-		    "Status",
-		    "Info",
-		    "Debug",
-		    "Trace"};
-
-		return std::string(levelName[(int)level]);
-	}
-
 	void Flush() override
 	{
-		if (m_logfile != NULL) {
-			fflush(m_logfile);
-		}
+		for (FILE* lf : m_log_files)
+			fflush(lf);
 	}
 
 private:
-	bool m_console;
 	//	bool m_gui;
-	FILE* m_logfile;
-	boost::mutex m_mutex;
+	std::vector<FILE*> m_log_files;
+	std::mutex m_mutex;
 };
 
 
@@ -177,54 +204,45 @@ void Logger::ShowDebugWindow(bool show)
 */
 }
 
-extern void lsllogerror(const char* format, ...)
+extern void LOG_PROGRESS(long /*done*/, long /*total*/, bool /*forceOutput*/)
 {
-	char buf[1024];
-	va_list args;
-	va_start(args, format);
-	const int len = vsnprintf(buf, 1024, format, args);
-	va_end(args);
-	if (len > 0) {
-		const std::string msg(buf, len);
-		wxLogWarning("Error: FIXME: %s", msg.c_str()); //FIXME: lsl throws a lot of errors
-	}
 }
 
-extern void lsllogdebug(const char* format, ...)
+void LOG_DISABLE(bool /*disableLogging*/)
 {
-	char buf[1024];
-	va_list args;
-	va_start(args, format);
-	const int len = vsnprintf(buf, 1024, format, args);
-	va_end(args);
-	if (len > 0) {
-		const std::string msg(buf, len);
-		wxLogDebug("%s", msg.c_str());
-	}
 }
 
-extern void lsllogwarning(const char* format, ...)
+extern void L_LOG(const char* fileName, int line, const char* funcName,
+           L_LEVEL level, const char* format...)
 {
-	char buf[1024];
 	va_list args;
 	va_start(args, format);
-	const int len = vsnprintf(buf, 1024, format, args);
+	char buf[1024];
+	// for some reason wxLogger().LogV() fails on windows, see #826
+	const int res = vsnprintf(buf, sizeof(buf), format, args);
 	va_end(args);
-	if (len > 0) {
-		const std::string msg(buf, len);
-		wxLogWarning("%s", msg.c_str());
-	}
-}
 
-extern void lslloginfo(const char* format, ...)
-{
-	char buf[1024];
-	va_list args;
-	va_start(args, format);
-	const int len = vsnprintf(buf, 1024, format, args);
-	va_end(args);
-	if (len > 0) {
-		const std::string msg(buf, len);
-		wxLogInfo("%s", msg.c_str());
+	wxLogLevel lvl;
+	switch (level) {
+		case L_RAW:
+			lvl = wxLOG_Debug;
+			break;
+		default:
+		case L_ERROR:
+			lvl = wxLOG_Error;
+			break;
+		case L_WARN:
+			lvl = wxLOG_Warning;
+			break;
+		case L_INFO:
+			lvl = wxLOG_Info;
+			break;
+		case L_DEBUG:
+			lvl = wxLOG_Debug;
+			break;
 	}
+
+	assert(res >= 0);
+	const wxLogRecordInfo info(fileName, line, funcName, PRD_LOG_COMPONENT);
+	wxLog::OnLog(lvl, buf, info);
 }
