@@ -381,7 +381,8 @@ void TASServer::Login()
 		localaddr = "*";
 	m_id_transmission = false;
 	SendCmd("LOGIN", stdprintf("%s %s 0 %s %s\t%u\ta m sp cl p",
-				   GetUserName().c_str(), pass.c_str(), localaddr.c_str(), getSpringlobbyAgent().c_str(), m_crc.GetCRC()));
+	  GetUserName().c_str(), pass.c_str(), localaddr.c_str(),
+	  GetSpringlobbyAgent().c_str(), m_crc.GetCRC()));
 	m_id_transmission = true;
 }
 
@@ -431,7 +432,8 @@ void TASServer::Notify()
 	if (m_last_ping > PING_TIME) { //Send a PING every 30 seconds
 		if (interval > PING_TIME) {
 			m_last_net_packet = 0; //assume local clock is broken and we received a packed within time
-			m_se->OnServerMessage(stdprintf("Springlobby hung or stale clock. Got no timer for %d msec", interval));
+			m_se->OnServerMessage(stdprintf("%s hung or stale clock. Got no timer for %d msec",
+			  GetSpringlobbyName().c_str(), interval));
 		}
 		m_last_ping = 0;
 		Ping();
@@ -976,22 +978,25 @@ void TASServer::ParseJson(const std::string& jsonstr)
 	}
 
 	if (!js.isObject()) {
-		wxLogWarning("Invalid json, object excepted: %s", jsonstr.c_str());
+		m_se->OnServerMessage(stdprintf("Invalid json, object excepted: %s", jsonstr.c_str()));
+		return;
+	}
+	if (js["FAILED"].isObject()) {
+		m_se->OnServerMessage(js["FAILED"]["msg"].asString());
 		return;
 	}
 
-	if (!js["SAID"].isObject()) {
-		wxLogWarning("Invalid json, object excepted: %s", jsonstr.c_str());
+	if (js["SAID"].isObject()) {
+		Json::Value said = js["SAID"];
+		cfg().Write(wxString::Format("/Channels/%s/lastid", said["chanName"].asString()), said["id"].asInt());
+		m_se->OnChannelSaid(said["chanName"].asString(), said["userName"].asString(), said["msg"].asString());
+		//TODO: store last id for channel
+		//said["time"].asInt64();
+		//said["id"].asUInt64();
 		return;
 	}
 
-	Json::Value said = js["SAID"];
-	cfg().Write(wxString::Format("/Channels/%s/lastid", said["chanName"].asString()), said["id"].asInt());
-	m_se->OnChannelSaid(said["chanName"].asString(), said["userName"].asString(), said["msg"].asString());
-
-	//TODO: store last id for channel
-	//said["time"].asInt64();
-	//said["id"].asUInt64();
+	wxLogWarning("Unknown command received: %s", jsonstr.c_str());
 }
 
 
