@@ -2,7 +2,7 @@
 
 set -e
 
-COMMIT=34451075836cdd23cb03b69ef285cf4a4ac9489f
+COMMIT=0dcf498f9563fd35eff0273e1b56929fdce60383
 
 if [ ! -d mxe ]; then
 	git clone https://github.com/mxe/mxe.git
@@ -17,9 +17,9 @@ git reset --hard $COMMIT
 
 (
 	echo 'JOBS := 2'
-	echo 'MXE_TARGETS := i686-w64-mingw32.static'
+	echo 'MXE_TARGETS := i686-w64-mingw32.static.posix'
 	echo 'LOCAL_PKG_LIST := openssl boost curl wxwidgets'
-	echo '.DEFAULT local-pkg-list:'
+	echo '.DEFAULT_GOAL  := local-pkg-list'
 	echo 'local-pkg-list: $(LOCAL_PKG_LIST)'
 ) > settings.mk
 
